<a name="0.2.3"></a>
### 0.2.3 (2015-01-29)


#### Bug Fixes

* another change to evalAsync

<a name="0.2.2"></a>
### 0.2.2 (2015-01-27)


#### Bug Fixes

* onLoad called in the middle of the options ([5b1a3170](http://github.com/angular-ui/ui-ace/commit/5b1a3170acd482ded223cc21f31fcbf62964f4d4))
* change to evalAsync

<a name="0.2.1"></a>
### 0.2.1 (2015-01-11)


#### Bug Fixes

* bad user callback digestion ([df526049](http://github.com/angular-ui/ui-ace/commit/df5260499ee83acd14fd2fd513f5fc19cec51f11))


<a name="0.2.0"></a>
### 0.2.0 (2015-01-08)


#### Bug Fixes

* ngModel put back the hack ([415610f0](http://github.com/angular-ui/ui-ace/commit/415610f0dcdc1116267e6aa4045bd5ae356f1fdc))
* ngModel update ([491369a9](http://github.com/angular-ui/ui-ace/commit/491369a9d508c28ad880ad707e35c3d827c0a71a), closes [#77](http://github.com/angular-ui/ui-ace/issues/77))


#### Features

* readonly ng ready ([0d99e5fd](http://github.com/angular-ui/ui-ace/commit/0d99e5fd65a9870617b9010111b72f789e276c8b))
* add advancedRenderer options ([76fc37d1](http://github.com/angular-ui/ui-ace/commit/76fc37d176ffe1e62dc72da4e85c027446794a64))
* **config:** always call the global onLoad handler ([c83086ac](http://github.com/angular-ui/ui-ace/commit/c83086ac7be7ff08dd632ab6705c43ba39ca6867))
* **directive:**
  * worker path for concatenated and minified configurations ([b7e20c1a](http://github.com/angular-ui/ui-ace/commit/b7e20c1aa6c4871a62b48fbb36a7a6794809d2b0))
  * require and advanced options ([6e160cb6](http://github.com/angular-ui/ui-ace/commit/6e160cb6f12b11365e8480509332951ea43d7e5a))


<a name="0.1.2"></a>
### 0.1.2 (2015-01-08)


<a name="0.1.1"></a>
### 0.1.1 (2015-01-08)


#### Bug Fixes

* **ace:** resize editor when its width/height changes ([b2024c14](http://github.com/angular-ui/ui-ace/commit/b2024c14dc6336bc232e1bb0b124b6be26f2bbee), closes [#26](http://github.com/angular-ui/ui-ace/issues/26))


<a name="v0.1.0"></a>
## v0.1.0 (2013-12-28)


#### Bug Fixes

* **publisher:** remove typo ([15a99e22](http://github.com/angular-ui/ui-ace/commit/15a99e22d4b761845abc7e7644b88d7eb45ee538))
* **travis:**
  * use node 0.10 ([588f6f1f](http://github.com/angular-ui/ui-ace/commit/588f6f1fc6fbca76b82db4e1e1c0a1d34d2a9835))
  * use angular-ui-publisher ([126de946](http://github.com/angular-ui/ui-ace/commit/126de946574f857919010bf3e2f7e46f52629b23))
* **ui-ace:** call $destroy when removed ([edb4fa14](http://github.com/angular-ui/ui-ace/commit/edb4fa149b8d2c9dbb7314a69e5d58dbc688fc0d))

<a name="v0.0.5"></a>
### v0.0.5 (2013-12-14)


#### Bug Fixes

* **demo:** Correct indentation. ([3482eaa2](http://github.com/angular-ui/ui-ace/commit/3482eaa2b570e6818e652d4ce116974511b8732c))
* **travis:**
  * Run bower install twice to make sure it does ([6c909f6b](http://github.com/angular-ui/ui-ace/commit/6c909f6b444f7d1ce67f1c4e7e0245ba83c75700))
  * Travis scripts bug... ([bbae258e](http://github.com/angular-ui/ui-ace/commit/bbae258e30c8a87fa3694422207b20a750729177))
* **ui-ace:** issue with digest already in progress error ([1b2dcd51](http://github.com/angular-ui/ui-ace/commit/1b2dcd516e430915f698d574513f93bb1bce4b68))


#### Features

* **demo:**
  * Add more demos ! ([5a2be000](http://github.com/angular-ui/ui-ace/commit/5a2be000fae6936a5a260e636feb9674de2e782e))
  * Add a demo.css file ([83bbacd5](http://github.com/angular-ui/ui-ace/commit/83bbacd54cbabb7eb7a9b072f09c589251db57c7))
  * Add angular-ui-bootstrap-bower for tabset directive. ([df6a1b67](http://github.com/angular-ui/ui-ace/commit/df6a1b67067105220e7e4b0b600275653a97f47a))
* **test:** add test code for the readOnly option ([5da05ab7](http://github.com/angular-ui/ui-ace/commit/5da05ab7b3f8a45f06cdc0e19655e7efcffdeb64))
* **ui-ace:**
  * Make the readonly option use double-curly expressions. Close #3. ([2115d615](http://github.com/angular-ui/ui-ace/commit/2115d61529bd4f9ec4db4f95a414ebd2396ef7ad))
  * add readOnly option ([cffd1e45](http://github.com/angular-ui/ui-ace/commit/cffd1e454ebcf24ebafa18830e20ab8ef4f5c27e))

